@@ -1,6 +1,6 @@
 #' Norwegian characters in unicode
 #' @export nor_char
-nor_char <- new.env(parent = emptyenv())
+nor_char <- new.env()
 nor_char$AA <- "\u00C5"
 nor_char$aa <- "\u00E5"
 nor_char$OE <- "\u00D8"
